@@ -57,6 +57,8 @@ about_name = 'Panucci'
 about_text = _('Resuming audiobook and podcast player')
 about_authors = ['Thomas Perl', 'nikosapi', 'Matthew Taylor']
 about_website = 'http://panucci.garage.maemo.org/'
+about_bugtracker = 'http://bugs.maemo.org/enter_bug.cgi?product=Panucci'
+about_donate = 'http://gpodder.org/donate'
 app_version = ''
 donate_wishlist_url = 'http://www.amazon.de/gp/registry/2PD2MYGHE6857'
 donate_device_url = 'http://maemo.gpodder.org/donate.html'
@@ -833,14 +835,20 @@ class GTK_Main(object):
         return settings.progress_locked
 
     def show_about(self, w, win):
+        from he.about import HeAboutDialog
+
         authors = ', '.join(about_authors[:-1])
 	authors += ' and ' + about_authors[-1]
-	message = '%s %s for Maemo 5\n%s\n\nBrought to you by %s. Maemo 5 UI by Thomas Perl.\n\nPlease consider supporting the gPodder project if you like Panucci. See http://gpodder.org/donate - thanks!' % (
-			about_name, app_version,
-			about_website, authors)
-	dlg = hildon.hildon_note_new_information(self.main_window, message)
-	dlg.run()
-	dlg.destroy()
+
+        HeAboutDialog.present(self.main_window,
+                about_name,
+                'panucci',
+                app_version,
+                about_text,
+                '(c) 2008-2010 ' + authors,
+                about_website,
+                about_bugtracker,
+                about_donate)
 
     def destroy(self, widget):
         player.quit()
